@@ -137,8 +137,8 @@ KJavaAppletServer::KJavaAppletServer()
 {
     process = new KJavaProcess();
 
-    connect( process, SIGNAL(received(const QByteArray&)),
-             this,    SLOT(slotJavaRequest(const QByteArray&)) );
+    connect( process, SIGNAL(received(QByteArray)),
+             this,    SLOT(slotJavaRequest(QByteArray)) );
 
     setupJava( process );
 
@@ -154,9 +154,11 @@ KJavaAppletServer::KJavaAppletServer()
 
 KJavaAppletServer::~KJavaAppletServer()
 {
+    disconnect(process, 0, 0, 0); // first disconnect from process.
     quit();
 
     delete process;
+    process = 0;
     delete d;
 }
 
@@ -199,7 +201,7 @@ void KJavaAppletServer::freeJavaServer()
         if( group.readEntry( "ShutdownAppletServer", true )  )
         {
             const int value = group.readEntry( "AppletServerTimeout", 60 );
-            QTimer::singleShot( value*1000, self, SLOT( checkShutdown() ) );
+            QTimer::singleShot( value*1000, self, SLOT(checkShutdown()) );
         }
     }
 }
@@ -479,7 +481,7 @@ void KJavaAppletServer::slotJavaRequest( const QByteArray& qb )
 
     //get contextID
     QString contextID;
-    while( qb[index] != 0 && index < qb_size )
+    while( index < qb_size && qb[index] != 0 )
     {
         contextID += qb[ index++ ];
     }
@@ -656,7 +658,7 @@ void KJavaAppletServer::slotJavaRequest( const QByteArray& qb )
                 QString text;
                 QList<KSSLCertificate *> certs;
                 for (int i = certsnr - 1; i >= 0; --i) {
-                    const QByteArray &arg = args[i + 2].toAscii();
+                    const QByteArray &arg = args[i + 2].toLatin1();
                     KSSLCertificate * cert = KSSLCertificate::fromString(arg.constData());
                     if (cert) {
                         certs.prepend(cert);
@@ -806,25 +808,29 @@ QString PermissionDialog::exec( const QString & cert, const QString & perm ) {
     buttonLayout->setObjectName("buttonLayout");
 
     QPushButton* const no = new QPushButton( i18n("&No"), dialog );
+    no->setObjectName( "no" );
     no->setDefault( true );
     buttonLayout->addWidget( no );
 
     QPushButton* const reject = new QPushButton( i18n("&Reject All"), dialog );
+    reject->setObjectName( "reject" );
     buttonLayout->addWidget( reject );
 
     QPushButton* const yes = new QPushButton( i18n("&Yes"), dialog );
+    yes->setObjectName( "yes" );
     buttonLayout->addWidget( yes );
 
     QPushButton* const grant = new QPushButton( i18n("&Grant All"), dialog );
+    grant->setObjectName( "grant" );
     buttonLayout->addWidget( grant );
     dialogLayout->addLayout( buttonLayout );
     dialog->resize( dialog->minimumSizeHint() );
     //clearWState( WState_Polished );
 
-    connect( no, SIGNAL( clicked() ), this, SLOT( clicked() ) );
-    connect( reject, SIGNAL( clicked() ), this, SLOT( clicked() ) );
-    connect( yes, SIGNAL( clicked() ), this, SLOT( clicked() ) );
-    connect( grant, SIGNAL( clicked() ), this, SLOT( clicked() ) );
+    connect( no, SIGNAL(clicked()), this, SLOT(clicked()) );
+    connect( reject, SIGNAL(clicked()), this, SLOT(clicked()) );
+    connect( yes, SIGNAL(clicked()), this, SLOT(clicked()) );
+    connect( grant, SIGNAL(clicked()), this, SLOT(clicked()) );
 
     dialog->exec();
     delete dialog;
