@@ -21,12 +21,10 @@
 #define DATAENGINE_P_H
 
 #include <QQueue>
-#include <QTime>
+#include <QElapsedTimer>
 
 #include <kplugininfo.h>
 
-class QTime;
-
 namespace Plasma
 {
 
@@ -35,7 +33,7 @@ class Service;
 class DataEnginePrivate
 {
     public:
-        DataEnginePrivate(DataEngine *e, KService::Ptr service);
+        DataEnginePrivate(DataEngine *e, const KPluginInfo &info);
         ~DataEnginePrivate();
         DataContainer *source(const QString &sourceName, bool createWhenMissing = true);
         void connectSource(DataContainer *s, QObject *visualization, uint pollingInterval,
@@ -84,13 +82,30 @@ class DataEnginePrivate
          */
         void sourceDestroyed(QObject *object);
 
+        /**
+         * stores the source
+         * @param sourceName the name of the source to store
+         */
+        void storeSource(DataContainer *source) const;
+
+        /**
+         * stores all sources marked for storage
+         */
+        void storeAllSources();
+
+        /**
+         * retrieves source data
+         * @param the data container to populate
+         */
+        void retrieveStoredData(DataContainer *s);
+
         DataEngine *q;
         KPluginInfo dataEngineDescription;
         int refCount;
         int checkSourcesTimerId;
         int updateTimerId;
         int minPollingInterval;
-        QTime updateTimestamp;
+        QElapsedTimer updateTimer;
         DataEngine::SourceDict sources;
         QQueue<DataContainer*> sourceQueue;
         QString icon;
@@ -101,6 +116,7 @@ class DataEnginePrivate
         QString serviceName;
         Package *package;
         Service *publishedService;
+        QString waitingSourceRequest;
 };
 
 } // Plasma namespace
